summaryrefslogtreecommitdiffstats
path: root/korn/label.h
diff options
context:
space:
mode:
Diffstat (limited to 'korn/label.h')
-rw-r--r--korn/label.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/korn/label.h b/korn/label.h
index d3c87ae9..18d4cb29 100644
--- a/korn/label.h
+++ b/korn/label.h
@@ -19,20 +19,20 @@
#ifndef MK_LABEL_H
#define MK_LABEL_H
-#include <qlabel.h>
-#include <qevent.h>
+#include <tqlabel.h>
+#include <tqevent.h>
/**
* A simple overriding of the QLabel class to get a mouseButtonPressed() signal
*/
class Label : public QLabel
{ Q_OBJECT
public:
- Label( QWidget * parent = 0, const char * name = 0 ) : QLabel( parent, name ) {}
+ Label( TQWidget * parent = 0, const char * name = 0 ) : TQLabel( parent, name ) {}
virtual ~Label() {}
protected:
- virtual void mousePressEvent( QMouseEvent *e ) { emit mouseButtonPressed( e->button() ); }
+ virtual void mousePressEvent( TQMouseEvent *e ) { emit mouseButtonPressed( e->button() ); }
signals:
/**
* Emitted when a button is pressed.
@@ -19,20 +19,20 @@
/**
- * A simple overriding of the QLabel class to get a mouseButtonPressed() signal
+ * A simple overriding of the TQLabel class to get a mouseButtonPressed() signal
*/
class Label : public QLabel